'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _swPrecache = require('sw-precache');

var _swPrecache2 = _interopRequireDefault(_swPrecache);

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var generateSWPrecacheConfig = function generateSWPrecacheConfig(_ref, extraSWPrecacheConfig) {
  var root = _ref.root,
      public_dir = _ref.public_dir,
      logger = _ref.logger;

  var hexoPublicDir = 'public';
  var rootPrefix = root.replace(/\/$/, '');
  return Object.assign({
    logger,
    replacePrefix: rootPrefix,
    staticFileGlobs: [hexoPublicDir + '/**/*.{js,html,css,png,jpg,gif,svg,eot,ttf,woff}'],
    stripPrefix: hexoPublicDir
  }, extraSWPrecacheConfig);
};

var runSWPrecache = function runSWPrecache() {
  var public_dir = this.public_dir,
      config = this.config,
      log = this.log;
  var root = config.root,
      offline = config.offline;

  // early return when no index.html presets in public directory

  var indexHTMLPath = _path2.default.join(public_dir, 'index.html');
  if (!_fs2.default.existsSync(indexHTMLPath)) {
    return Promise.resolve();
  }

  var SWPrecacheConfig = generateSWPrecacheConfig({ root, public_dir, logger: log.info.bind(log) }, offline);

  return _swPrecache2.default.write(_path2.default.join(public_dir, _constants.workerName), SWPrecacheConfig);
};

exports.default = runSWPrecache;